=== modified file 'AllDayEventComponent.qml'
--- AllDayEventComponent.qml	2014-04-05 06:36:28 +0000
+++ AllDayEventComponent.qml	2014-03-19 00:32:29 +0000
@@ -3,6 +3,7 @@
 import Ubuntu.Components.Popups 0.1
 
 import "dateExt.js" as DateExt
+import "GlobalEventModel.js" as GlobalModel
 import "ViewType.js" as ViewType
 
 Rectangle{
@@ -10,7 +11,6 @@
 
     property var allDayEvents;
     property var startDay: DateExt.today();
-    property var model;
 
     property int type: ViewType.ViewTypeWeek
 
@@ -20,9 +20,10 @@
 
     function getAllDayEvents(startDate, endDate) {
         var map = {};
-        var items = model.getItems(startDate,endDate);
-        for(var i = 0 ; i < items.length ; ++i) {
-            var event = items[(i)];
+        var itemIds = GlobalModel.globalModel().itemIds(startDate, endDate);
+        for(var i = 0 ; i < itemIds.length ; ++i) {
+            var eventId = itemIds[(i)];
+            var event = GlobalModel.globalModel().item(eventId);            
             if( event && event.allDay ) {
                 var key  = Qt.formatDateTime(event.startDateTime, "dd-MMM-yyyy");
                 if( !(key in map)) {
@@ -43,6 +44,15 @@
         allDayEvents = getAllDayEvents(sd,ed);
     }
 
+    Component.onCompleted: {
+        var model = GlobalModel.globalModel();
+        model.reloaded.connect(root.createAllDayEvents);
+    }
+
+    onStartDayChanged: {
+        createAllDayEvents();
+    }
+
     Row {
         width: parent.width
         anchors.verticalCenter: parent.verticalCenter
@@ -71,7 +81,7 @@
                             if( allDayLabel.events.length > 1 ) {
                                 PopupUtils.open(popoverComponent, root,{"events": allDayLabel.events})
                             } else {
-                                pageStack.push(Qt.resolvedUrl("EventDetails.qml"),{"event":allDayLabel.events[0],"model": model});
+                                pageStack.push(Qt.resolvedUrl("EventDetails.qml"),{"event":allDayLabel.events[0]});
                             }
                         }
                     }
@@ -138,7 +148,7 @@
                         anchors.fill: parent
                         onClicked: {
                             popover.hide();
-                            pageStack.push(Qt.resolvedUrl("EventDetails.qml"),{"event":modelData,"model": model});
+                            pageStack.push(Qt.resolvedUrl("EventDetails.qml"),{"event":modelData});
                         }
                     }
                 }

=== modified file 'EventBubble.qml'
--- EventBubble.qml	2014-03-26 14:29:37 +0000
+++ EventBubble.qml	2014-03-22 03:56:27 +0000
@@ -10,8 +10,6 @@
     property int wideType: 1;
     property int narrowType: 2;
 
-    property Flickable flickable;
-
     readonly property int minimumHeight: timeLabel.height
 
     signal clicked(var event);
@@ -70,41 +68,10 @@
             if( event.displayLabel)
                 timeLabel.text = event.displayLabel;
         }
-
-        layoutBubbleDetails();
-    }
-
-    function layoutBubbleDetails() {
-        if(!flickable || flickable === undefined ) {
-            return;
-        }
-
-        if( infoBubble.y < flickable.contentY && infoBubble.height > flickable.height) {
-            var y = (flickable.contentY - infoBubble.y) * 1.2;
-            if( (y+ detailsColumn.height) > infoBubble.height) {
-                y = infoBubble.height - detailsColumn.height;
-            }
-            detailsColumn.y = y;
-        }
-    }
-
-    Connections{
-        target: flickable
-        onContentYChanged: {
-            layoutBubbleDetails();
-        }
-    }
-    Connections{
-        target: detailsColumn
-        onHeightChanged: {
-            layoutBubbleDetails();
-        }
     }
 
     Column{
-        id: detailsColumn
         width: parent.width
-
         Row{
             width: parent.width
 

=== modified file 'EventDetails.qml'
--- EventDetails.qml	2014-04-05 06:31:50 +0000
+++ EventDetails.qml	2014-02-19 11:39:13 +0000
@@ -5,6 +5,7 @@
 import Ubuntu.Components.Themes.Ambiance 0.1
 import QtOrganizer 5.0
 
+import "GlobalEventModel.js" as GlobalModel
 import "Defines.js" as Defines
 
 Page {
@@ -13,8 +14,6 @@
     property var event;
     property string headerColor :"black"
     property string detailColor :"grey"
-    property var model;
-
     anchors.fill: parent
     Component.onCompleted: {
         if( pageStack.header )
@@ -52,6 +51,11 @@
             titleLabel.text = e.displayLabel;
         }
 
+        var location = "";
+        if( e.location ) {
+            locationLabel.text = e.location;
+            location = e.location;
+        }
         if( e.description ) {
             descLabel.text = e.description;
         }
@@ -59,7 +63,7 @@
         contactModel.clear();
         if( attendees !== undefined ) {
             for( var j = 0 ; j < attendees.length ; ++j ) {
-                contactModel.append( {"name": attendees[j].name,"participationStatus": attendees[j].participationStatus }  );
+                contactModel.append( {"name": attendees[j].name } );
             }
         }
 
@@ -79,20 +83,12 @@
         }
         reminderHeader.value = Defines.reminderLabel[index];
 
-        if( e.location ) {
-            locationLabel.text = e.location;
 
-            // FIXME: need to cache map image to avoid duplicate download every time
-            var imageSrc = "http://maps.googleapis.com/maps/api/staticmap?center="+e.location+
-                    "&markers=color:red|"+e.location+"&zoom=15&size="+mapContainer.width+
-                    "x"+mapContainer.height+"&sensor=false";
-            mapImage.source = imageSrc;
-        }
-        else {
-            // TODO: use different color for empty text
-            locationLabel.text = i18n.tr("Not specified")
-            mapImage.source = "";
-        }
+        // FIXME: need to cache map image to avoid duplicate download every time
+        var imageSrc = "http://maps.googleapis.com/maps/api/staticmap?center="+location+
+                "&markers=color:red|"+location+"&zoom=15&size="+mapContainer.width+
+                "x"+mapContainer.height+"&sensor=false";
+        mapImage.source=imageSrc;
     }
 
     tools: ToolbarItems {
@@ -102,7 +98,8 @@
                 text: i18n.tr("Delete");
                 iconSource: "image://theme/delete,edit-delete-symbolic"
                 onTriggered: {
-                    model.removeItem(event);
+                    var eventModel = GlobalModel.globalModel();
+                    eventModel.removeItem(event);
                     pageStack.pop();
                 }
             }
@@ -113,7 +110,7 @@
                 text: i18n.tr("Edit");
                 iconSource: Qt.resolvedUrl("edit.svg");
                 onTriggered: {
-                   pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"event":event,"model":model});
+                   pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"event":event});
                 }
             }
         }
@@ -198,7 +195,6 @@
                 id: mapContainer
                 width:parent.width
                 height: units.gu(10)
-                visible: mapImage.status == Image.Ready
 
                 Image {
                     id: mapImage
@@ -225,10 +221,7 @@
                 }
                 delegate: Row{
                     spacing: units.gu(1)
-                    CheckBox{
-                     checked: participationStatus
-                     enabled: false
-                    }
+                    CheckBox{}
                     Label {
                         text:name
                         anchors.verticalCenter:  parent.verticalCenter

=== modified file 'EventListModel.qml'
--- EventListModel.qml	2014-04-05 04:49:47 +0000
+++ EventListModel.qml	2014-02-26 13:42:20 +0000
@@ -1,26 +1,16 @@
 import QtQuick 2.0
+import "dateExt.js" as DateExt
+
 import QtOrganizer 5.0
 
 OrganizerModel {
     id: eventModel
     manager:"eds"
-
-    property var listeners:[];
-
-    function addModelChangeListener(listener){
-        listeners.push(listener);
-    }
-
-    function getItems(startDate, endDate){
-        return itemsByTimePeriod(startDate,endDate);
-    }
+    autoUpdate: false
+
+    signal reloaded
 
     onModelChanged: {
-        if(listeners === undefined){
-            return;
-        }
-        for(var i=0; i < listeners.length ;++i){
-            (listeners[i])();
-        }
+        reloaded();
     }
 }

=== added file 'GlobalEventModel.js'
--- GlobalEventModel.js	1970-01-01 00:00:00 +0000
+++ GlobalEventModel.js	2014-01-31 03:20:40 +0000
@@ -0,0 +1,9 @@
+.pragma library
+
+var model;
+function globalModel() {
+    if( !model) {
+        model = Qt.createQmlObject('import QtQuick 2.0; EventListModel {}', Qt.application, 'EventListModel.globalModel()')
+    }
+    return model;
+}

=== modified file 'HeaderDateComponent.qml'
--- HeaderDateComponent.qml	2014-04-02 10:38:06 +0000
+++ HeaderDateComponent.qml	2013-10-28 21:08:48 +0000
@@ -1,7 +1,7 @@
 import QtQuick 2.0
 import Ubuntu.Components 0.1
 
-Item {
+Column{
     id: root
 
     property var date;
@@ -11,40 +11,25 @@
 
     property int dayFormat: Locale.ShortFormat;
 
-    signal dateSelected(var date);
-
     width: parent.width
-    height: innerColumn.height
+    spacing: units.gu(2)
 
-    Column {
-        id: innerColumn
+    Label{
+        id: dayLabel
+        property var day: Qt.locale().standaloneDayName(date.getDay(), dayFormat)
+        text: day.toUpperCase();
+        fontSize: "medium"
+        horizontalAlignment: Text.AlignHCenter
+        color: "#AEA79F"
         width: parent.width
-        spacing: units.gu(2)
-
-        Label{
-            id: dayLabel
-            property var day: Qt.locale().standaloneDayName(date.getDay(), dayFormat)
-            text: day.toUpperCase();
-            fontSize: "medium"
-            horizontalAlignment: Text.AlignHCenter
-            color: "#AEA79F"
-            width: parent.width
-        }
-
-        Label{
-            id: dateLabel
-            objectName: "dateLabel"
-            text: date.getDate();
-            fontSize: "large"
-            horizontalAlignment: Text.AlignHCenter
-            width: parent.width
-        }
     }
 
-    MouseArea {
-        anchors.fill: parent
-        onClicked: {
-            root.dateSelected(date);
-        }
+    Label{
+        id: dateLabel
+        objectName: "dateLabel"
+        text: date.getDate();
+        fontSize: "large"
+        horizontalAlignment: Text.AlignHCenter
+        width: parent.width
     }
 }

=== modified file 'NewEvent.qml'
--- NewEvent.qml	2014-04-05 04:49:47 +0000
+++ NewEvent.qml	2014-02-19 11:39:13 +0000
@@ -6,6 +6,7 @@
 import Ubuntu.Components.Themes.Ambiance 0.1
 import QtOrganizer 5.0
 
+import "GlobalEventModel.js" as GlobalModel
 import "Defines.js" as Defines
 
 Page {
@@ -13,7 +14,6 @@
     property var date: new Date();
 
     property var event:null;
-    property var model;
 
     property var startDate;
     property var endDate;
@@ -33,8 +33,9 @@
         // If endDate is setted by argument we have to not change it
         if (typeof(endDate) === 'undefined') {
             endDate = new Date(date)
-            endDate.setMinutes( endDate.getMinutes() + 30)
+            endDate.setMinutes( endDate.getMinutes() + 10)
         }
+        internal.eventModel = GlobalModel.globalModel();
 
         if(event === null){
             isEdit =false;
@@ -51,7 +52,7 @@
         event = Qt.createQmlObject("import QtOrganizer 5.0; Event { }", Qt.application,"NewEvent.qml");
         startDate = new Date(date)
         endDate = new Date(date)
-        endDate.setMinutes( endDate.getMinutes() + 30)
+        endDate.setMinutes( endDate.getMinutes() + 10)
 
         startTime.text = Qt.formatDateTime(startDate, "dd MMM yyyy hh:mm");
         endTime.text = Qt.formatDateTime(endDate, "dd MMM yyyy hh:mm");
@@ -153,25 +154,11 @@
                 event.setDetail(audibleReminder);
             }
 
-            model.saveItem(event);
+            internal.eventModel.saveItem(event);
             pageStack.pop();
         }
     }
 
-    // Calucate default hour for start and end time on event
-    function hourForPickerFromDate(date) {
-        if(date.getMinutes() < 30)
-            return date.getHours()
-        return date.getHours() + 1
-    }
-
-    // Calucate default minute for start and end time on event
-    function minuteForPickerFromDate(date) {
-        if(date.getMinutes() < 30)
-            return 30
-        return 0
-    }
-
     width: parent.width
     height: parent.height
 
@@ -282,7 +269,7 @@
                             anchors.fill: parent
                             onClicked: {
                                 internal.clearFocus()
-                                var popupObj = PopupUtils.open(timePicker,root,{"hour": root.hourForPickerFromDate(startDate),"minute":root.minuteForPickerFromDate(startDate)});
+                                var popupObj = PopupUtils.open(timePicker,root,{"hour": startDate.getHours(),"minute":startDate.getMinutes()});
                                 popupObj.accepted.connect(function(startHour, startMinute) {
                                     var newDate = startDate;
                                     newDate.setHours(startHour, startMinute);
@@ -307,7 +294,7 @@
                             anchors.fill: parent
                             onClicked: {
                                 internal.clearFocus()
-                                var popupObj = PopupUtils.open(timePicker,root,{"hour": root.hourForPickerFromDate(endDate),"minute":root.minuteForPickerFromDate(endDate)});
+                                var popupObj = PopupUtils.open(timePicker,root,{"hour": endDate.getHours(),"minute":endDate.getMinutes()});
                                 popupObj.accepted.connect(function(startHour, startMinute) {
                                     var newDate = endDate;
                                     newDate.setHours(startHour, startMinute);
@@ -425,6 +412,7 @@
 
     QtObject {
         id: internal
+        property var eventModel;
 
         function clearFocus() {
             Qt.inputMethod.hide()

=== modified file 'TimeLineBase.qml'
--- TimeLineBase.qml	2014-04-05 05:00:55 +0000
+++ TimeLineBase.qml	2014-03-26 14:39:17 +0000
@@ -1,6 +1,7 @@
 import QtQuick 2.0
 import Ubuntu.Components 0.1
 import "dateExt.js" as DateExt
+import "GlobalEventModel.js" as GlobalModel
 
 Item {
     id: bubbleOverLay
@@ -9,38 +10,49 @@
     property var day;
     property int hourHeight: units.gu(10)
 
-    property var model;
+    Component.onCompleted: {
+        intern.model = GlobalModel.globalModel();
+        intern.model.reloaded.connect(bubbleOverLay.createEvents);
+    }
+
+    onDayChanged: {
+        if( intern.model)
+            bubbleOverLay.createEvents();
+    }
 
     TimeSeparator{
         id: separator
         objectName: "separator"
         width:  bubbleOverLay.width
-        visible: false
         z:1
     }
 
     QtObject {
         id: intern
         property var now : new Date();
+        property var model;
     }
 
     function showEventDetails(event) {
-        pageStack.push(Qt.resolvedUrl("EventDetails.qml"),{"event":event,"model":model});
+        pageStack.push(Qt.resolvedUrl("EventDetails.qml"),{"event":event});
     }
 
     function createEvents() {
         if(!bubbleOverLay || bubbleOverLay == undefined) {
             return;
         }
-        destroyAllChildren();
+
+        bubbleOverLay.destroyAllChildren();
 
         var startDate = new Date(day).midnight();
+
         var endDate = new Date(day).endOfDay();
 
-        var items = model.getItems(startDate,endDate);
-        for(var i = 0 ; i < items.length ; ++i) {
-            var event = items[i];
-            if(event.allDay === false) {
+        var itemIds = intern.model.itemIds(startDate,endDate);
+        for(var i = 0 ; i < itemIds.length ; ++i) {
+            var eventId = itemIds[(i)];
+            var event = intern.model.item(eventId);
+            if( event ) {
                 bubbleOverLay.createEvent(event,event.startDateTime.getHours());
             }
         }
@@ -52,8 +64,10 @@
 
     function destroyAllChildren() {
         for( var i = children.length - 1; i >= 0; --i ) {
-            children[i].visible = false;
-            if( children[i].objectName !== "separator") {
+            if( children[i].objectName === "separator") {
+                children[i].visible = false;
+            } else {
+                children[i].visible = false;
                 children[i].destroy();
             }
         }
@@ -61,7 +75,6 @@
 
     function createEvent( event ,hour) {
         var eventBubble = delegate.createObject(bubbleOverLay);
-
         eventBubble.clicked.connect( bubbleOverLay.showEventDetails );
 
         var yPos = (( event.startDateTime.getMinutes() * hourHeight) / 60) + hour * hourHeight

=== modified file 'TimeLineBaseComponent.qml'
--- TimeLineBaseComponent.qml	2014-04-05 04:49:47 +0000
+++ TimeLineBaseComponent.qml	2014-03-22 04:43:11 +0000
@@ -27,13 +27,6 @@
         }
     }
 
-    EventListModel {
-        id: mainModel
-        startPeriod: startDay.midnight();
-        endPeriod: type == ViewType.ViewTypeWeek ? startPeriod.addDays(7).endOfDay(): startPeriod.endOfDay()
-    }
-
-
     Column {
         anchors.top: parent.top
 
@@ -44,10 +37,6 @@
             id: allDayContainer
             type: root.type
             startDay: root.startDay
-            model: mainModel
-            Component.onCompleted: {
-                model.addModelChangeListener(createAllDayEvents);
-            }
         }
 
         Flickable{
@@ -86,11 +75,6 @@
                         height: parent.height
                         delegate: comp
                         day: startDay.addDays(index)
-
-                        model: mainModel
-                        Component.onCompleted: {
-                            model.addModelChangeListener(createEvents);
-                        }
                     }
                 }
             }
@@ -111,7 +95,6 @@
             anchors.right: parent.right
             anchors.leftMargin: units.gu(0.1)
             anchors.rightMargin: units.gu(0.1)
-            flickable: timeLineView
             clip: true
         }
     }

=== modified file 'TimeLineHeader.qml'
--- TimeLineHeader.qml	2014-03-26 19:06:27 +0000
+++ TimeLineHeader.qml	2014-02-12 00:24:25 +0000
@@ -17,8 +17,6 @@
 
     property var date;
 
-    signal dateSelected(var date);
-
     DayHeaderBackground{
         height: FontUtils.sizeToPixels("medium") + units.gu(1.5)
     }
@@ -40,10 +38,6 @@
 
         startDay: getStartDate();
 
-        onDateSelected: {
-            header.dateSelected(date);
-        }
-
         function getStartDate() {
             switch(type) {
             case ViewType.ViewTypeWeek:

=== modified file 'TimeLineHeaderComponent.qml'
--- TimeLineHeaderComponent.qml	2014-03-26 19:06:27 +0000
+++ TimeLineHeaderComponent.qml	2014-01-31 03:20:40 +0000
@@ -13,8 +13,6 @@
     property var startDay: DateExt.today();
     property bool isCurrentItem: false
 
-    signal dateSelected(var date);
-
     width: parent.width
 
     Repeater{
@@ -47,10 +45,6 @@
                     header.width
                 }
             }
-
-            onDateSelected: {
-                header.dateSelected(date);
-            }
         }
     }
 }

=== modified file 'WeekView.qml'
--- WeekView.qml	2014-04-05 04:57:34 +0000
+++ WeekView.qml	2014-03-26 14:39:17 +0000
@@ -12,8 +12,6 @@
     property var firstDay: dayStart.weekStart(Qt.locale().firstDayOfWeek);
     property bool isCurrentPage: false
 
-    signal dateSelected(var date);
-
     anchors.fill: parent
     anchors.top: parent.top
     anchors.topMargin: units.gu(1.5)
@@ -29,16 +27,15 @@
         id: weekHeader
         objectName: "weekHeader"
         type: ViewType.ViewTypeWeek
-        date: firstDay
-
-        onDateSelected: {
-            root.dateSelected(date);
-        }
+        date: weekViewPath.weekStart
     }
 
     PathViewBase{
         id: weekViewPath
 
+        property var visibleWeek: dayStart.weekStart(Qt.locale().firstDayOfWeek);
+        property var weekStart: weekViewPath.visibleWeek
+
         width: parent.width
         height: root.height - weekViewPath.y
 
@@ -56,11 +53,13 @@
         }
 
         function nextWeek() {
-            dayStart = firstDay.addDays(7);
+            var weekStartDay = visibleWeek.weekStart(Qt.locale().firstDayOfWeek);
+            dayStart = weekStartDay.addDays(7);
         }
 
         function previousWeek(){
-            dayStart = firstDay.addDays(-7);
+            var weekStartDay = visibleWeek.weekStart(Qt.locale().firstDayOfWeek);
+            dayStart = weekStartDay.addDays(-7);
         }
 
         delegate: TimeLineBaseComponent {
@@ -71,7 +70,7 @@
             width: parent.width
             height: parent.height
 
-            startDay: firstDay.addDays( weekViewPath.indexType(index) * 7)
+            startDay: getWeekStart();
 
             Connections{
                 target: root
@@ -97,6 +96,19 @@
                 value: contentY
                 when: timeLineView.PathView.isCurrentItem
             }
+
+            function getWeekStart() {
+                switch( weekViewPath.indexType(index)) {
+                case 0:
+                    return weekViewPath.weekStart;
+                case -1:
+                    var weekStartDay= weekViewPath.weekStart.weekStart(Qt.locale().firstDayOfWeek);
+                    return weekStartDay.addDays(-7);
+                case 1:
+                    var weekStartDay = weekViewPath.weekStart.weekStart(Qt.locale().firstDayOfWeek);
+                    return weekStartDay.addDays(7);
+                }
+            }
         }
     }
 }

=== modified file 'YearView.qml'
--- YearView.qml	2014-04-04 02:14:33 +0000
+++ YearView.qml	2014-03-22 03:07:26 +0000
@@ -23,7 +23,6 @@
     delegate: GridView{
         id: yearView
         clip: true
-        focus: index == root.currentIndex
 
         property bool isCurrentItem: index == root.currentIndex
         property int year: (root.currentYear + root.indexType(index))

=== modified file 'calendar.qml'
--- calendar.qml	2014-04-05 06:34:47 +0000
+++ calendar.qml	2014-03-26 14:39:17 +0000
@@ -3,6 +3,7 @@
 import Ubuntu.Components.Popups 0.1
 
 import "dateExt.js" as DateExt
+import "GlobalEventModel.js" as GlobalModel
 
 MainView {
     id: mainView
@@ -50,7 +51,7 @@
     objectName: "calendar"
     applicationName: "com.ubuntu.calendar"
 
-    width: units.gu(100)
+    width: units.gu(45)
     height: units.gu(80)
 
     headerColor: "#266249"
@@ -67,6 +68,7 @@
             id: tabPage
 
             property var currentDay: DateExt.today();
+            property var globalModel;
 
             // Arguments on startup
             property bool newevent: false;
@@ -86,6 +88,18 @@
 
                 if( !weekView.dayStart.isSameDay(currentDay))
                     weekView.dayStart = currentDay
+
+                setStartEndDateToModel();
+            }
+
+            function setStartEndDateToModel() {
+                if(globalModel) {
+                    globalModel.startPeriod =  new Date(currentDay.getFullYear(),0,1,0,0,0,0);
+                    globalModel.endPeriod = new Date(currentDay.getFullYear(),11,31,0,0,0,0);
+                    // only enable auto update after set the date interval
+                    globalModel.autoUpdate = true
+                    globalModel.update()
+                }
             }
 
             function newEvent() {
@@ -110,7 +124,7 @@
                             endDate = new Date(endTime);
                     }
                 }
-                pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"startDate": startDate, "endDate": endDate, "model":eventModel});
+                pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"startDate": startDate, "endDate": endDate});
             }
 
             // This function calculate the difference between --endtime and --starttime and choose the better view
@@ -145,6 +159,7 @@
 
                 if (endtimepattern.test(url))
                     endtime = url.match(/endtime=(\d+)/)[0].replace("endtime=", '');
+
             }
 
             Component.onCompleted: {
@@ -179,6 +194,9 @@
                 else {
                     tabs.selectedTabIndex= 1;
                 }
+
+                globalModel = GlobalModel.globalModel();
+                setStartEndDateToModel();
             } // End of Component.onCompleted:
 
             // This is for wait that the app is load when newEvent is invoked by argument
@@ -192,13 +210,6 @@
                 }
             }
 
-            EventListModel{
-                id: eventModel
-                //This model is just for newevent
-                //so we dont need any update
-                autoUpdate: false
-            }
-
             ToolbarItems {
                 id: commonToolBar
 
@@ -218,7 +229,7 @@
                         iconSource: Qt.resolvedUrl("new-event.svg");
                         text: i18n.tr("New Event");
                         onTriggered: {
-                            pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"date":tabPage.currentDay,"model":eventModel});
+                            pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"date":tabPage.currentDay});
                         }
                     }
                 }
@@ -279,11 +290,6 @@
                             onDayStartChanged: {
                                 tabPage.currentDay = dayStart;
                             }
-
-                            onDateSelected: {
-                                tabs.selectedTabIndex = 3;
-                                tabPage.currentDay = date;
-                            }
                         }
                     }
                 }

=== modified file 'po/ar.po'
--- po/ar.po	2014-04-02 06:45:37 +0000
+++ po/ar.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-11-20 22:16+0000\n"
 "Last-Translator: Ibrahim Saed <ibraheem5000@gmail.com>\n"
 "Language-Team: Arabic <ar@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "أضف دعوة"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "حرّر"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "أشخاص"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "انشئ حدث"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "اضف اسم الحدث"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "إلى"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "الموقع والأشخاص"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "أضف مكانا"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "دعوة أشخاص"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "خطأ"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "موافق"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "احفظ"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "وقت الانتهاء لا يمكن أن يكون قبل وقت البدء"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "حدث جديد"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "إلغاء"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "احفظ"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "خطأ"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "الدقيقة"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "موافق"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "إلغاء"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "حدث جديد"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "اليوم"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "السنة"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "الشهر"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "الأسبوع"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "اليوم"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "التقويم"

=== modified file 'po/ast.po'
--- po/ast.po	2014-04-04 07:08:10 +0000
+++ po/ast.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
-"PO-Revision-Date: 2014-04-04 02:27+0000\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
+"PO-Revision-Date: 2014-01-14 20:54+0000\n"
 "Last-Translator: Xuacu Saturio <xuacusk8@gmail.com>\n"
 "Language-Team: Asturian <ast@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-04 07:08+0000\n"
-"X-Generator: Launchpad (build 16976)\n"
-
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr "%1E"
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr "%1 Actividaes pal día enteru"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
+"X-Generator: Launchpad (build 16967)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr "Desaniciar"
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Amestar invitación"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Editar"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr "Principiu"
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr "Fin"
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr "Actividá pal día enteru:"
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr "Llugar"
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr "Invitaos"
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr "Asocede esto"
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr "Recordámelo"
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Xente"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Crear eventu"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Amestar el nome del eventu"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "a"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Llocalización y persones"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Amestar llocalización"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Invitar xente"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Error"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Aceutar"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Guardar"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "El tiempu final nun pue ser anterior al d'aniciu"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr "Editar actividá"
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Nueva actividá"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Encaboxar"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Guardar"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Error"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr "Aceutar"
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr "Data"
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr "Nome de l'actividá"
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr "Descripción"
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,39 +100,34 @@
 msgid "Minute"
 msgstr "Minutu"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Aceutar"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-"La app de calendariu aceuta trés argumentos: --starttime, --endtime y --"
-"newevet. Estos xestionarálos el sistema. Vea'l códigu fonte pa un comentariu "
-"completu d'ellos"
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Encaboxar"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Nueva actividá"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Güei"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Añu"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mes"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Selmana"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Día"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendariu"

=== modified file 'po/az.po'
--- po/az.po	2014-04-02 06:45:37 +0000
+++ po/az.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-11-20 11:12+0000\n"
 "Last-Translator: Emin Mastizada <emin25@ovi.com>\n"
 "Language-Team: Azerbaijani <az@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Dəvət əlavə et"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Redaktə"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "İnsanlar"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Tədbir yarat"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Tədbir adı əlavə et"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "kimə"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Mövqelər və İnsanlar"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Ünvan Əlavə Et"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "İnsanları Dəvət et"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Xəta"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "ОК"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Qeyd et"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Bitmə vaxtı başlama vaxtından əvvəl ola bilməz"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Yeni Tədbir"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Ləğv et"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Qeyd et"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Xəta"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Dəqiqə"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "ОК"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Ləğv et"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Yeni Tədbir"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Bu gün"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "İl"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Ay"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Həftə"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Gün"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Təqvim"

=== modified file 'po/be.po'
--- po/be.po	2014-04-02 06:45:37 +0000
+++ po/be.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-06-22 15:09+0000\n"
 "Last-Translator: Maksim Tomkowicz <quendimax@gmail.com>\n"
 "Language-Team: Belarusian <be@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Дадаць запрашэнне"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Змяніць"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Новая падзея"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Людзі"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Стварыць падзею"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Дадаць назву падзеі"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Дадаць месца"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Запрасіць людзей"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "Захаваць"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Новая падзея"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Каляндар"

=== modified file 'po/bg.po'
--- po/bg.po	2014-04-02 06:45:37 +0000
+++ po/bg.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
-"PO-Revision-Date: 2014-04-01 18:39+0000\n"
-"Last-Translator: Atanas Kovachki <Unknown>\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
+"PO-Revision-Date: 2014-01-25 16:34+0000\n"
+"Last-Translator: Gangov <Unknown>\n"
 "Language-Team: Bulgarian <bg@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "чч:мм"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr "Изтрий"
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Добави покана"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
-msgstr "Редактирай"
-
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr "Старт"
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr "Край"
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr "Местоположение"
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr "Гости"
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr "Напомни"
-
-#: ../NewEvent.qml:106
+msgstr "Редактиране"
+
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Хора"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Създай събитие"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Добави име на събитието"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "до"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Местоположение и хора"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Добавяне на местоположение"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Покани хора"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Грешка"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "ОК"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Запазване"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Времето за край не може да бъде преди времето за начало"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr "Редактирай събитието"
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Ново събитие"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Отмени"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Съхрани"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Грешка"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr "Добре"
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr "Дата"
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr "Име на събитието"
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr "Описвание"
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Минута"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Добре"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Отмени"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Ново събитие"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Днес"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Година"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Месец"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Седмица"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Ден"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Календар"

=== modified file 'po/br.po'
--- po/br.po	2014-04-02 06:45:37 +0000
+++ po/br.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-03-05 10:24+0000\n"
 "Last-Translator: Fohanno Thierry <thierry.fohanno@ofis-bzh.org>\n"
 "Language-Team: Breton <br@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "ee:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Ouzhpennañ ur perzhiad"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Aozañ"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Tud"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Krouiñ un darvoud"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Ouzhpennañ anv an darvoud"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "da"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Lec'h & Tud"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Ouzhpennañ ul lec'h"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Pediñ tud"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Fazi"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Mat eo"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Enrollañ"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Ne c'hall ket ar fin bezañ a-raok an deroù"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Darvoud nevez"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Nullañ"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Enrollañ"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Fazi"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Munutenn"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Mat eo"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Nullañ"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Darvoud nevez"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Hiziv"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Bloaz"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Miz"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Sizhun"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Deiz"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Deiziadur"

=== modified file 'po/ca.po'
--- po/ca.po	2014-04-02 06:45:37 +0000
+++ po/ca.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-06-14 09:42+0000\n"
 "Last-Translator: David Planella <david.planella@ubuntu.com>\n"
 "Language-Team: Catalan <ca@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Afegeix una invitació"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Edita"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Esdeveniment nou"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Gent"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Crea un esdeveniment"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Afegeix un nom a l'esdeveniment"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Afegeix una ubicació"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Convida persones"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "Desa"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Esdeveniment nou"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendari"

=== modified file 'po/calendar-app.pot'
--- po/calendar-app.pot	2014-03-11 00:04:28 +0000
+++ po/calendar-app.pot	2013-10-07 13:24:09 +0000
@@ -1,6 +1,6 @@
-# Calendar App Translations
-# Copyright (C) 2014 Canonical Ltd.
-# This file is distributed under the same license as the ubuntu-calendar-app package.
+# SOME DESCRIPTIVE TITLE.
+# Copyright (C) YEAR Canonical Ltd.
+# This file is distributed under the same license as the PACKAGE package.
 # FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
 #
 #, fuzzy
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: calendar-app\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -17,105 +17,71 @@
 "Content-Type: text/plain; charset=CHARSET\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/ckb.po'
--- po/ckb.po	2014-04-02 06:45:37 +0000
+++ po/ckb.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-02-24 16:32+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Kurdish (Sorani) <ckb@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/cs.po'
--- po/cs.po	2014-04-03 06:02:27 +0000
+++ po/cs.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
-"PO-Revision-Date: 2014-04-02 08:20+0000\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
+"PO-Revision-Date: 2014-01-07 09:08+0000\n"
 "Last-Translator: Tadeáš Pařík <tadeas.parik@gmail.com>\n"
 "Language-Team: Czech <cs@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-03 06:02+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr "%1E"
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr "%1 Celodenní udalosti"
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr "Smazat"
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Přidat pozvánku"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Upravit"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr "Začátek"
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr "Konec"
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr "Celodenní událost:"
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr "Místo"
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr "Hosté"
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr "Toto se děje"
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr "Připomenutí"
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Osoby"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Vytvořit událost"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Přidat název události"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "Pro"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Umístění & lidé"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Přidat umístění"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Pozvat lidi"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Chyba"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Uložit"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Čas ukončení nemůže být před začátkem události"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr "Upravit událost"
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Nová událost"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Zrušit"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Uložit"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Chyba"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr "Ok"
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr "Datum"
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr "Název události"
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr "Popis"
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,39 +100,34 @@
 msgid "Minute"
 msgstr "Minuta"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-"Aplikace kalendář pracuje se třemi typy parametrů: --starttime, --endtime a -"
-"-newevet. Jsou spravovány systémem. Pro přístup k úplnému popisu je potřeba "
-"nahlédnout do zdrojových dat."
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Zrušit"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Nová událost"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Dnes"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Rok"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Měsíc"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Týden"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Den"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Kalendář"

=== modified file 'po/cy.po'
--- po/cy.po	2014-04-02 06:45:37 +0000
+++ po/cy.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-13 12:02+0000\n"
 "Last-Translator: Owen Llywelyn <owen.llywelyn@gmail.com>\n"
 "Language-Team: Welsh <cy@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Ychwanegu gwahoddiad"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Golygu"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Pobl"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Creu digwyddiad"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Ychwanegu enw digwyddiad"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "i"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Lleoliad & Pobl"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Ychwanegu Lleoliad"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Gwahodd Pobl"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Gwall"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Iawn"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Cadw"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Gall amser gorffen ddim bod cyn amser cychwyn"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Digwyddiad Newydd"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Diddymu"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Cadw"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Gwall"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Munud"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Iawn"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Diddymu"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Digwyddiad Newydd"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Heddiw"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Blwyddyn"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mis"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Wythnos"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Diwrnod"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendr"

=== modified file 'po/de.po'
--- po/de.po	2014-04-02 06:45:37 +0000
+++ po/de.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-18 12:27+0000\n"
 "Last-Translator: Phillip Sz <Unknown>\n"
 "Language-Team: German <de@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Einladung hinzufügen"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Bearbeiten"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Personen"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Termin anlegen"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Terminbezeichnung hinzufügen"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "bis"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Standort & Personen"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Ort hinzufügen"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Personen einladen"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Fehler"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Speichern"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Endzeit kann nicht vor der Startzeit liegen."
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Neuer Termin"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Abbrechen"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Speichern"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Fehler"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minute"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Abbrechen"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Neuer Termin"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Heute"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Jahr"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Monat"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Woche"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Tag"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Kalender"

=== modified file 'po/el.po'
--- po/el.po	2014-04-02 06:45:37 +0000
+++ po/el.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-03-01 13:45+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Greek <el@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/en_AU.po'
--- po/en_AU.po	2014-04-02 06:45:37 +0000
+++ po/en_AU.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-28 07:40+0000\n"
 "Last-Translator: Jared Norris <jarednorris@ubuntu.com>\n"
 "Language-Team: English (Australia) <en_AU@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Add invite"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Edit"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "People"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Create event"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Add event name"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "to"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Location & People"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Add Location"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Invite People"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Error"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Save"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "End time can't be before start time"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "New Event"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Cancel"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Save"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Error"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minute"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Cancel"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "New Event"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Today"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Year"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Month"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Week"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Day"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendar"

=== modified file 'po/en_CA.po'
--- po/en_CA.po	2014-04-02 06:45:37 +0000
+++ po/en_CA.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-07-03 22:35+0000\n"
 "Last-Translator: Shayne White <shayne.s.white@gmail.com>\n"
 "Language-Team: English (Canada) <en_CA@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Add invite"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Edit"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "New Event"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "People"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Create event"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Add event name"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Add Location"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Invite People"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "Save"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "New Event"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendar"

=== modified file 'po/en_GB.po'
--- po/en_GB.po	2014-04-02 06:45:37 +0000
+++ po/en_GB.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-28 09:13+0000\n"
 "Last-Translator: Jackson Doak <Doak.jackson@gmail.com>\n"
 "Language-Team: English (United Kingdom) <en_GB@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Add invite"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Edit"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "People"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Create event"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Add event name"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "to"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Location & People"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Add Location"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Invite People"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Error"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Save"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "End time can't be before start time"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "New Event"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Cancel"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Save"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Error"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minute"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Cancel"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "New Event"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Today"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Year"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Month"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Week"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Day"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendar"

=== modified file 'po/eo.po'
--- po/eo.po	2014-04-02 06:45:37 +0000
+++ po/eo.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-05-18 17:00+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Esperanto <eo@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/es.po'
--- po/es.po	2014-04-02 06:45:37 +0000
+++ po/es.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-01-14 19:25+0000\n"
 "Last-Translator: Jose Luis Tirado <Unknown>\n"
 "Language-Team: Spanish <es@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Añadir invitado"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Editar"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Personas"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Crear evento"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Añadir el nombre del evento"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "hasta"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Ubicación y personas"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Añadir ubicación"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Invitar personas"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Error"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Aceptar"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Guardar"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "La hora de finalización no puede ser anterior a la hora de inicio"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Evento nuevo"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Cancelar"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Guardar"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Error"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minuto"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Aceptar"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Cancelar"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Evento nuevo"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Hoy"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Año"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mes"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Semana"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Día"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendario"

=== modified file 'po/et.po'
--- po/et.po	2014-04-02 06:45:37 +0000
+++ po/et.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-07-07 14:22+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Estonian <et@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/eu.po'
--- po/eu.po	2014-04-02 06:45:37 +0000
+++ po/eu.po	2014-03-23 06:44:27 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-03-22 19:19+0000\n"
 "Last-Translator: Ibai Oihanguren Sala <Unknown>\n"
 "Language-Team: Basque <eu@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-23 06:44+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Gehitu gonbidapena"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Editatu"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Partaideak"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Sortu gertaera"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Gehitu gertaeraren izena"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "honi:"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Kokalekua eta partaideak"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Gehitu kokalekua"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Gonbidatu jendea"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Errorea"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Ados"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Gorde"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Amaierako ordua ezin da hasierakoa baino lehenago izan"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Gertaera berria"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Utzi"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Gorde"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Errorea"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minutuak"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Ados"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Utzi"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Gertaera berria"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Gaur"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Urtea"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Hila"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Astea"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Eguna"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Egutegia"

=== modified file 'po/fa.po'
--- po/fa.po	2014-04-02 06:45:37 +0000
+++ po/fa.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-08 12:03+0000\n"
 "Last-Translator: MohamadReza Mirdamadi <Unknown>\n"
 "Language-Team: Persian <fa@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "اضافه کردن دعوت"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "ویرایش"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "افراد"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "ساختن رویداد"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "افزودن نام رویداد"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "به"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "مکانها و افراد"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "افزودن مکان"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "دعوت‌کردن افراد"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "خطا"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "تایید"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "ذخیره‌کردن"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "زمان پایان نمیتواند قبل از زمان آغاز باشد"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "رویداد تازه"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "انصراف"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "ذخیره‌کردن"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "خطا"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "دقیقه"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "تایید"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "انصراف"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "رویداد تازه"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "امروز"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "سال"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "ماه"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "هفته"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "روز"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "تقویم"

=== modified file 'po/fi.po'
--- po/fi.po	2014-04-02 06:45:37 +0000
+++ po/fi.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-03-09 20:57+0000\n"
 "Last-Translator: Jiri Grönroos <Unknown>\n"
 "Language-Team: Finnish <fi@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Lisää kutsu"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Muokkaa"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Ihmiset"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Luo tapahtuma"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Lisää tapahtuman nimi"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "-"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Sijainti ja ihmiset"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Lisää sijainti"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Kutsu ihmisiä"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Virhe"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Tallenna"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Päättymisaika ei voi olla ennen aloitusaikaa"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Uusi tapahtuma"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Peru"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Tallenna"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Virhe"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minuutti"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Peru"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Uusi tapahtuma"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Tänään"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Vuosi"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Kuukausi"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Viikko"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Päivä"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Kalenteri"

=== modified file 'po/fr.po'
--- po/fr.po	2014-04-02 06:45:37 +0000
+++ po/fr.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-30 18:21+0000\n"
 "Last-Translator: Sylvie Gallet <Unknown>\n"
 "Language-Team: French <fr@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Ajouter un participant"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Modifier"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Participants"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Créer un évènement"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Ajouter un nom à l'événement"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "à"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Lieu et participants"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Ajouter un emplacement"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Inviter des participants"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Erreur"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Enregistrer"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "L'heure de fin ne peut pas précéder l'heure de début"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Nouvel évènement"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Annuler"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Enregistrer"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Erreur"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minute"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Annuler"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Nouvel évènement"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Aujourd'hui"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Année"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mois"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Semaine"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Jour"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Agenda"

=== modified file 'po/gd.po'
--- po/gd.po	2014-04-02 06:45:37 +0000
+++ po/gd.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-28 20:54+0000\n"
 "Last-Translator: Akerbeltz <fios@akerbeltz.org>\n"
 "Language-Team: Gaelic; Scottish <gd@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Cuir cuireadh ris"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Deasaich"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Daoine"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Cruthaich tachartas"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Thoir ainm air an tachartas"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "gu"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Ionad ⁊ daoine"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Cuir ionad ris"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Thoir cuireadh do dhaoine"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Mearachd"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Ceart ma-thà"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Sàbhail"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Chan fhaod e crìochnachadh mus tòisich e"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Tachartas ùr"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Sguir dheth"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Sàbhail"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Mearachd"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Mionaid"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Ceart ma-thà"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Sguir dheth"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Tachartas ùr"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "An-diugh"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Bliadhna"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mìos"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Seachdain"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Latha"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Am mìosachan"

=== modified file 'po/gl.po'
--- po/gl.po	2014-04-02 06:45:37 +0000
+++ po/gl.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-01 15:13+0000\n"
 "Last-Translator: Marcos Lans <Unknown>\n"
 "Language-Team: Galician <gl@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Engadir convite"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Editar"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Persoas"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Crear unha actividade"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Engadir o nome da actividade"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "até"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Localización e persoas"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Engadir localización"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Convidar persoas"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Erro"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Aceptar"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Gardar"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "A hora de remate non pode ser anterior ao inicio"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Nova actividade"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Cancelar"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Gardar"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Erro"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minuto"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Aceptar"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Cancelar"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Nova actividade"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Hoxe"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Ano"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mes"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Semana"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Día"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendario"

=== modified file 'po/gu.po'
--- po/gu.po	2014-04-02 06:45:37 +0000
+++ po/gu.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-08-07 10:33+0000\n"
 "Last-Translator: Bhaumik Shukla <boom.shukla@gmail.com>\n"
 "Language-Team: Gujarati <gu@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "આમંત્રિત ઉમેરો"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "ફેરફાર કરો"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "નવી ઘટના"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "લોકો"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "ઘટના બનાવો"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "ઘટના નું નામ ઉમેરો"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "સ્થળ ઉમેરો"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "લોકોને આમંત્રિત કરો"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "સાચવો"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "નવી ઘટના"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "કેલેન્ડર"

=== modified file 'po/he.po'
--- po/he.po	2014-04-02 06:45:37 +0000
+++ po/he.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-29 13:08+0000\n"
 "Last-Translator: Yaron <sh.yaron@gmail.com>\n"
 "Language-Team: Hebrew <he@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "הוספת הזמנה"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "עריכה"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "אנשים"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "יצירת אירוע"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "הוספת שם לאירוע"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "עד"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "מיקום ואנשים"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "הוספת מיקום"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "הזמנת אנשים"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "שגיאה"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "אישור"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "שמירה"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "מועד הסיום לא יכול להקדים את מועד ההתחלה"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "אירוע חדש"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "ביטול"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "שמירה"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "שגיאה"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "דקה"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "אישור"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "ביטול"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "אירוע חדש"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "היום"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "שנה"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "חודש"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "שבוע"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "יום"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "לוח שנה"

=== modified file 'po/hi.po'
--- po/hi.po	2014-04-02 06:45:37 +0000
+++ po/hi.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-06-12 12:13+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Hindi <hi@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/hr.po'
--- po/hr.po	2014-04-02 06:45:37 +0000
+++ po/hr.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-07-30 11:28+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Croatian <hr@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/hu.po'
--- po/hu.po	2014-04-02 06:45:37 +0000
+++ po/hu.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-01-05 00:55+0000\n"
 "Last-Translator: Mátó Péter <Unknown>\n"
 "Language-Team: Hungarian <hu@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Meghívó hozzáadása"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Szerkesztés"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Emberek"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Esemény létrehozása"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Esemény nevének megadása"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "eddig:"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Hely és személyek"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Hely hozzáadása"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Emberek meghívása"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Hiba"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Mentés"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "A végződés időpontjának a kezdés után kell lennie."
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Új esemény"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Mégse"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Mentés"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Hiba"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Perc"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Mégse"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Új esemény"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Ma"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Év"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Hónap"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Hét"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Nap"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Naptár"

=== modified file 'po/id.po'
--- po/id.po	2014-04-02 06:45:37 +0000
+++ po/id.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-02-11 09:43+0000\n"
 "Last-Translator: Dirgita <Unknown>\n"
 "Language-Team: Indonesian <id@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Tambah undangan"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Sunting"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Kenalan"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Buat acara"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Tambah nama acara"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "hingga"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Lokasi & Kenalan"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Tambah Lokasi"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Undang Kenalan"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Galat"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Oke"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Simpan"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Waktu akhir tak mungkin sebelum waktu mulai"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Acara Baru"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Batal"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Simpan"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Galat"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Menit"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Oke"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Batal"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Acara Baru"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Hari ini"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Tahun"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Bulan"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Minggu"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Hari"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Kalender"

=== modified file 'po/it.po'
--- po/it.po	2014-04-02 06:45:37 +0000
+++ po/it.po	2014-03-21 06:52:40 +0000
@@ -7,116 +7,82 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-07 09:48+0000\n"
 "Last-Translator: Claudio Arseni <claudio.arseni@gmail.com>\n"
 "Language-Team: Italian <it@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Aggiungi invito"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Modifica"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Invitati"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Crea evento"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Aggiungi il nome all'evento"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "a"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Località e invitati"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Aggiungi località"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Invita persone"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Errore"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Salva"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 "L'ora di fine dell'evento non può essere precedente a quella dell'inizio"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Nuovo evento"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Annulla"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Salva"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Errore"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -135,36 +101,34 @@
 msgid "Minute"
 msgstr "Minuti"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Annulla"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Nuovo evento"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Oggi"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Anno"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mese"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Settimana"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Giorno"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendario"

=== modified file 'po/ja.po'
--- po/ja.po	2014-04-02 06:45:37 +0000
+++ po/ja.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-01-18 14:44+0000\n"
 "Last-Translator: Shushi Kurose <md81bird@hitaki.net>\n"
 "Language-Team: Japanese <ja@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "編集"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "新しいイベント"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "キャンセル"
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "予定を作成する"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "場所の追加"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "保存"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "分"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "キャンセル"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "新しいイベント"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "年"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "月"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "週"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "日"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "カレンダー"

=== modified file 'po/ka.po'
--- po/ka.po	2014-04-02 06:45:37 +0000
+++ po/ka.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-07-15 18:37+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Georgian <ka@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/km.po'
--- po/km.po	2014-04-02 06:45:37 +0000
+++ po/km.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-11 02:46+0000\n"
 "Last-Translator: Khoem Sokhem <khoemsokhem@khmeros.info>\n"
 "Language-Team: Khmer <km@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "បន្ថែម​ការ​អញ្ជើញ"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "កែសម្រួល"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "មនុស្ស"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "បង្កើតព្រឹត្តិការណ៍"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "បន្ថែម​ឈ្មោះព្រឹត្តិការណ៍"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "ទៅ"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "ទីតាំង & មនុស្ស"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "បន្ថែម​ទីតាំង"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "អញ្ជើញមនុស្ស"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "កំហុស"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "យល់ព្រម"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "រក្សាទុក"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "ពេល​វេលា​បញ្ចប់​មិន​អាច​មុន​ពេលវេលា​ចាប់ផ្ដើម"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "ព្រឹត្តិការណ៍​ថ្មី"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "បោះ​បង់"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "រក្សាទុក"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "កំហុស"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "នាទី"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "យល់ព្រម"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "បោះ​បង់"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "ព្រឹត្តិការណ៍​ថ្មី"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "ថ្ងៃ​នេះ"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "ឆ្នាំ"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "ខែ"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "សប្ដាហ៍"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "ថ្ងៃ"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "ប្រតិទិន"

=== modified file 'po/ko.po'
--- po/ko.po	2014-04-02 06:45:37 +0000
+++ po/ko.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-05-18 13:58+0000\n"
 "Last-Translator: Jinkyu Yi <Unknown>\n"
 "Language-Team: Korean <ko@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "고치기"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "새 이벤트"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "사람들"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "새 이벤트 만들기"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "이벤트 이름 넣기"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "위치 넣기"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "오는 사람들"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "저장"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "새 이벤트"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/lo.po'
--- po/lo.po	2014-04-02 06:45:37 +0000
+++ po/lo.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-02 07:17+0000\n"
 "Last-Translator: Anousak <anousak@gmail.com>\n"
 "Language-Team: Lao <lo@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "ມມ:ນນ"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "ເພີ່ມເຊີນ"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "ດັດແກ້"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "ຄົນ"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "ສ້າງໂອກາດ"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "ເພີ່ມຊື່ໂອກາດ"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "ເຖີງ"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "ສະຖານທີ່ ແລະ ປະຊາຊົນ"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "ເພີ່ມສະຖານທີ່"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "ເຊີນຄົນ"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "ຜິດພາດ"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "ຕົກລົງ"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "ບັນທຶກ"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "ເວລາສຸດທ້າຍບໍ່ສາມາດຈະໃຊ້ເວລາກ່ອນຈະເລີ່ມຕົ້ນ"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "ໂອກາດໄໝ່"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "ຍົກເລີກ"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "ບັນທຶກ"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "ຜິດພາດ"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "ນາທີ"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "ຕົກລົງ"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "ຍົກເລີກ"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "ໂອກາດໄໝ່"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "ວົນນີ້"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "ປີ"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "ເດືອນ"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "ອາທິດ"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "ວັນ"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "ປະຕິທິນ"

=== modified file 'po/lv.po'
--- po/lv.po	2014-04-02 06:45:37 +0000
+++ po/lv.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-28 15:48+0000\n"
 "Last-Translator: Jānis-Marks Gailis <jeanmarc.gailis@gmail.com>\n"
 "Language-Team: Latvian <lv@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Pievienot ciemiņu"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Rediģēt"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Jauns notikums"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Atcelt"
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Cilvēki"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Pievienot pasākumu"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Pievienot pasākuma nosaukums"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "līdz"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Pievienot atrašanās vietu"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Uzaicināt cilvēkus"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Kļūda"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Labi"
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "Saglabāt"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Kļūda"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minūte"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Labi"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Atcelt"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Jauns notikums"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Šodien"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Gads"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mēnesis"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Nedēļa"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Diena"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Kalendārs"

=== modified file 'po/ms.po'
--- po/ms.po	2014-04-02 06:45:37 +0000
+++ po/ms.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-12-14 04:57+0000\n"
 "Last-Translator: abuyop <Unknown>\n"
 "Language-Team: Malay <ms@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Tambah jemputan"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Sunting"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Individu"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Cipta peristiwa"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Tambah nama peristiwa"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "kepada"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Lokasi & Individu"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Tambah Lokasi"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Jemput Individu"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Ralat"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Simpan"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Masa tamat tidak boleh lebih awal dari masa mula"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Peristiwa Baru"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Batal"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Simpan"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Ralat"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minit"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Batal"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Peristiwa Baru"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Hari ini"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Tahun"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Bulan"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Minggu"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Hari"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Kalendar"

=== modified file 'po/my.po'
--- po/my.po	2014-04-02 06:45:37 +0000
+++ po/my.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-12-11 10:34+0000\n"
 "Last-Translator: Pyae Sone <Unknown>\n"
 "Language-Team: Burmese <my@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "ဖိတ်ကြားမည်"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "ပြင်ဆင်"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "လူများ"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "ပွဲဖန်တီးမည်"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "ပွဲအမည်ထည့်မည်"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "သို့"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "တည်နေရာနှင့်လူများ"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "တည်နေရာပေါင်းထည့်မည်"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "လူများဖိတ်မည်"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "ချို့ယွင်းချက်"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "အိုကေ"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "သိမ်းမည်"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "အဆုံးသတ်သည့်အချိန်သည် စသည့်အချိန်ထက် မစောရပါ"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "ပွဲအသစ်"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "ပယ်ဖျက်မည်"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "သိမ်းမည်"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "ချို့ယွင်းချက်"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "မိနစ်"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "အိုကေ"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "ပယ်ဖျက်မည်"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "ပွဲအသစ်"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "ယနေ့"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "နှစ်"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "လ"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "အပတ်"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "နေ့ရက်"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "ပြက္ခဒိန်"

=== modified file 'po/nb.po'
--- po/nb.po	2014-04-02 06:45:37 +0000
+++ po/nb.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-06-21 16:14+0000\n"
 "Last-Translator: Mathias Bynke <Unknown>\n"
 "Language-Team: Norwegian Bokmal <nb@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Legg til invitasjon"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Rediger"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Ny hendelse"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Personer"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Opprett hendelse"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Legg til navn på hendelse"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Legg til sted"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Inviter folk"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "Lagre"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Ny hendelse"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Kalender"

=== modified file 'po/nl.po'
--- po/nl.po	2014-04-02 06:45:37 +0000
+++ po/nl.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-05 07:14+0000\n"
 "Last-Translator: Hannie Dumoleyn <Unknown>\n"
 "Language-Team: Dutch <nl@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Uitnodiging toevoegen"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Bewerken"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Personen"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Gebeurtenis aanmaken"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Naam gebeurtenis toevoegen"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "naar"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Locatie en personen"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Locatie toevoegen"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Personen uitnodigen"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Fout"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Opslaan"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Eindtijd kan niet voor begintijd zijn"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Nieuwe gebeurtenis"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Annuleren"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Opslaan"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Fout"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minuut"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Annuleren"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Nieuwe gebeurtenis"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Vandaag"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Jaar"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Maand"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Week"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Dag"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Agenda"

=== modified file 'po/pl.po'
--- po/pl.po	2014-04-02 06:45:37 +0000
+++ po/pl.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-02 19:45+0000\n"
 "Last-Translator: GTriderXC <gtriderxc@yahoo.com>\n"
 "Language-Team: Polish <pl@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Dodaj zaproszenie"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Edycja"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Ludzie"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Nowe wydarzenie"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Dodaj nazwę wydarzenia"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "do"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Miejsca i ludzie"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Dodaj lokalizację"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Zaproś uczestników"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Błąd"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Zapisz"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Czas zakończenia nie może zostać ustawiony przed czasem rozpoczęcia"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Nowe wydarzenie"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Anuluj"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Zapisz"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Błąd"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minuty"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Anuluj"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Nowe wydarzenie"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Dzisiaj"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Rok"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Miesiąc"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Tydzień"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Dzień"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Kalendarz"

=== modified file 'po/po.pro'
--- po/po.pro	2014-03-11 00:04:28 +0000
+++ po/po.pro	2013-09-26 05:49:31 +0000
@@ -10,13 +10,13 @@
 PROJECTNAME = $$system(basename ../*.qmlproject)
 PROJECTNAME = $$replace(PROJECTNAME,.qmlproject,)
 
-DESKTOPFILE = ../com.ubuntu.calendar_calendar.desktop.in
+DESKTOPFILE = ../$${PROJECTNAME}.desktop
 
 SOURCECODE = ../*.qml \
              ../*.js
 
 BUILDDIR = ../.build
-DESKTOPFILETEMP = $${BUILDDIR}/com.ubuntu.calendar_calendar.desktop.in
+DESKTOPFILETEMP = $${BUILDDIR}/$${PROJECTNAME}.desktop.js
 
 message("")
 message(" Project Name: $$PROJECTNAME ")

=== modified file 'po/pt.po'
--- po/pt.po	2014-04-02 06:45:37 +0000
+++ po/pt.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-01-14 20:49+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Portuguese <pt@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/pt_BR.po'
--- po/pt_BR.po	2014-04-02 06:45:37 +0000
+++ po/pt_BR.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-04 06:51+0000\n"
 "Last-Translator: Tiago Hillebrandt <tiagohillebrandt@gmail.com>\n"
 "Language-Team: Brazilian Portuguese <pt_BR@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Adicionar convite"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Editar"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Pessoas"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Criar evento"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Adicionar nome do evento"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "para"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Pessoas e locais"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Adicionar local"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Convidar pessoas"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Erro"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Salvar"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Horário final não pode ser antes do horário inicial"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Novo evento"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Cancelar"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Salvar"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Erro"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minuto"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Cancelar"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Novo evento"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Hoje"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Ano"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mês"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Semana"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Dia"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Calendário"

=== modified file 'po/ro.po'
--- po/ro.po	2014-04-02 06:45:37 +0000
+++ po/ro.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-05-17 21:55+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Romanian <ro@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/ru.po'
--- po/ru.po	2014-04-02 06:45:37 +0000
+++ po/ru.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-29 19:43+0000\n"
 "Last-Translator: Zonov Roman <Unknown>\n"
 "Language-Team: Russian <ru@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Добавить приглашение"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Изменить"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Люди"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Добавить событие"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Задать имя события"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "для"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Места и люди"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Добавить местоположение"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Пригласить людей"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Ошибка"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Сохранить"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Дата окончания не может быть раньше даты начала события"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Новое событие"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Отмена"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Сохранить"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Ошибка"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Минута"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "OK"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Отмена"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Новое событие"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Сегодня"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Год"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Месяц"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Неделя"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "День"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Календарь"

=== modified file 'po/shn.po'
--- po/shn.po	2014-04-02 06:45:37 +0000
+++ po/shn.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-07-14 08:39+0000\n"
 "Last-Translator: Sai Mawn Kham <Unknown>\n"
 "Language-Team: Shan <shn@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "ထႅမ်သႂ်ႇ ပၢင်ၵႅဝ်ႈ"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "မႄးထတ်း"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "ပၢင်ၵႅဝ်ႈ ဢၼ်မႂ်ႇ"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "ၵူၼ်း"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "ၵေႃႇသၢင်ႈ ပၢင်ၵႅဝ်ႈ"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "ထႅမ်သႂ်ႇ ၸိုဝ်ႈပၢင်ၵႅဝ်ႈ"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "ထႅမ်သႂ်ႇ ဢွင်ႈတီႈ"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "ၽိတ်ႈမွၵ်ႈ ၵူၼ်း"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "သိမ်း"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "ပၢင်ၵႅဝ်ႈ ဢၼ်မႂ်ႇ"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "ပၵ်းယဵမ်ႈဝၼ်း"

=== modified file 'po/sk.po'
--- po/sk.po	2014-04-02 06:45:37 +0000
+++ po/sk.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-08-29 16:18+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Slovak <sk@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/sl.po'
--- po/sl.po	2014-04-02 06:45:37 +0000
+++ po/sl.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-29 18:44+0000\n"
 "Last-Translator: Dražen Matešić <Unknown>\n"
 "Language-Team: Slovenian <sl@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Dodaj povabilo"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Uredi"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Ljudje"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Ustvari dogodek"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Dodaj ime dogodka"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "na"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Kraj in ljudje"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Dodaj mesto"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Povabi ljudi"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Napaka"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "V redu"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Shrani"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Končni čas ne more biti pred začetnim časom"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Nov dogodek"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Prekliči"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Shrani"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Napaka"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Minuta"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "V redu"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Prekliči"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Nov dogodek"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Danes"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Leto"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Mesec"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Teden"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Dan"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Koledar"

=== modified file 'po/sr.po'
--- po/sr.po	2014-04-02 06:45:37 +0000
+++ po/sr.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-06-24 10:56+0000\n"
 "Last-Translator: Данило Шеган <Unknown>\n"
 "Language-Team: Serbian <sr@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Додај позивницу"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Уреди"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Нови догађај"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Особе"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Направи догађај"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Додај назив догађаја"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Додај место"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Позови људе"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "Сачувај"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Нови догађај"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Календар"

=== modified file 'po/st.po'
--- po/st.po	2014-04-02 06:45:37 +0000
+++ po/st.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-02-13 09:04+0000\n"
 "Last-Translator: Pitso Mofokeng <pitso3000@gmail.com>\n"
 "Language-Team: Sotho, Southern <st@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Eketsa mema"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Hlophisa"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Batho"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Bopa ketsahalo"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Rea ketsahalo"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Madulo le Batho"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Eketsa madulo"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "mema batho"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Phoso"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Pesetsa"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Boloka"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "nako ya qalo etla pele nako ya ho fela"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Ketsahalo e Ntjha"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "phomola"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Boloka"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Phoso"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Motsotso"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Pesetsa"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "phomola"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Ketsahalo e Ntjha"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Kajeno"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Selemo"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Kgwedi"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Beke"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Letsatsi"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/sv.po'
--- po/sv.po	2014-04-02 06:45:37 +0000
+++ po/sv.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2014-02-15 11:54+0000\n"
 "Last-Translator: Daniel Holm <d.holmen@gmail.com>\n"
 "Language-Team: Swedish <sv@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Lägg till inbjudan"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Redigera"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Ny händelse"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Personer"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Skapa händelse"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Lägg till namn på händelse"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "till"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Plats & Person"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Lägg till plats"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Bjud in personer"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "Spara"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Ny händelse"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Kalender"

=== modified file 'po/ta.po'
--- po/ta.po	2014-04-02 06:45:37 +0000
+++ po/ta.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-26 05:34+0000\n"
-"Last-Translator: Arun Kumar -அருண் குமார் <thangam.arunx@gmail.com>\n"
+"Last-Translator: Thangamani Arun - தங்கமணி அருண் <thangam.arunx@gmail.com>\n"
 "Language-Team: Tamil <ta@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "அழைப்பை சேர்"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "திருத்து"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "மக்கள்"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "நிகழ்வை உருவாக்கு"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "நிகழ்வின் பெயரை சேர்"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "அதற்கு"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "இருப்பிடம் & மக்கள்"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "இடத்தை சேர்"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "மக்களை அழை"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "பிழை"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "சரி"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "சேமி"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "முடியும் நேரம் தொடங்கும் நேரத்திற்கு முன்னதாக இருக்க கூடாது"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "புதிய நிகழ்வு"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "ரத்துசெய்"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "சேமி"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "பிழை"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "நிமிடம்"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "சரி"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "ரத்துசெய்"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "புதிய நிகழ்வு"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "இன்று"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "ஆண்டு"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "மாதம்"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "வாரம்"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "நாள்"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "நாள்காட்டி"

=== modified file 'po/te.po'
--- po/te.po	2014-04-02 06:45:37 +0000
+++ po/te.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-07-13 18:04+0000\n"
 "Last-Translator: tuxnani(రహ్మానుద్దీన్ షేక్) <Unknown>\n"
 "Language-Team: Telugu <te@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "ఆహ్వానం చేర్చు"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "సవరించు"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "కొత్త సంఘటన"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "జనం"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "సంఘటనను సృష్టించు"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "సంఘటన పేరును చేర్చు"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "స్థానాన్ని చేర్చు"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "జనాన్ని ఆహ్వానించు"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "భద్రపరుచు"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "కొత్త సంఘటన"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "క్యాలెండర్"

=== modified file 'po/tr.po'
--- po/tr.po	2014-04-02 06:45:37 +0000
+++ po/tr.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-12-12 15:37+0000\n"
 "Last-Translator: Mesut Yaver <Unknown>\n"
 "Language-Team: Turkish <tr@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "ss:dd"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Davet ekle"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Düzenle"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Kişiler"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Etkinlik oluştur"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Etkinlik adı ekle"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "'na"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Yerler ve Kişiler"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Konum Ekle"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Kişi Davet Et"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Hata"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Tamam"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Kaydet"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Bitiş zamanı başlama zamanından önce olamaz"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Yeni Etkinlik"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "İptal"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Kaydet"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Hata"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Dakika"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Tamam"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "İptal"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Yeni Etkinlik"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Bugün"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Yıl"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Ay"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Hafta"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "Gün"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Takvim"

=== modified file 'po/ug.po'
--- po/ug.po	2014-04-02 06:45:37 +0000
+++ po/ug.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-11-12 23:54+0000\n"
 "Last-Translator: Gheyret T.Kenji <Unknown>\n"
 "Language-Team: Uyghur <ug@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "تەكلىپ قوش"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "تەھرىر"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "كىشىلەر"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "ھادىسە قۇر"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "ھادىسە ئاتىنى قوش"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "ئورۇن ۋە ئادەملەر"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "ئورۇن قوش"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "تونۇشلارنى تەكلىپ قىل"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "خاتالىق"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "تامام"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "ساقلا"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "ئاخىرلىشىش ۋاقتى باشلىنىش ۋاقتىدىن بۇرۇن بولسا بولمايدۇ"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "يېڭى ھادىسە"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "ئەمەلدىن قالدۇر"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "ساقلا"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "خاتالىق"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "مىنۇت"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "تامام"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "ئەمەلدىن قالدۇر"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "يېڭى ھادىسە"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "بۈگۈن"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "يىل"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "ئاي"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "ھەپتە"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "كۈن"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "يىلنامە"

=== modified file 'po/uk.po'
--- po/uk.po	2014-04-02 06:45:37 +0000
+++ po/uk.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-28 10:47+0000\n"
 "Last-Translator: Yuri Chornoivan <yurchor@gmail.com>\n"
 "Language-Team: Ukrainian <uk@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 — %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Додати запрошення"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Змінити"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Люди"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Створити запис події"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Додати назву події"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "до"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Місце і учасники"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Додати місце"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Запросити учасників"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Помилка"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Гаразд"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Зберегти"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "Момент завершення не може передувати моментові початку"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Нова подія"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "Скасувати"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "Зберегти"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "Помилка"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "Хвилина"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "Гаразд"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Скасувати"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Нова подія"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "Сьогодні"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "Рік"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "Місяць"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "Тиждень"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "День"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "Календар"

=== modified file 'po/vi.po'
--- po/vi.po	2014-04-02 06:45:37 +0000
+++ po/vi.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-05-18 09:22+0000\n"
 "Last-Translator: Vu Do Quynh <vdquynh@gmail.com>\n"
 "Language-Team: Vietnamese <vi@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Thêm lời mời"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "Sửa"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "Sự kiện Mới"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Người"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Tạo sự kiện"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Thêm tên sự kiện"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Thêm địa điểm"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "Mời Người"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "Lưu"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Sự kiện Mới"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/xh.po'
--- po/xh.po	2014-04-02 06:45:37 +0000
+++ po/xh.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-05-18 01:01+0000\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Xhosa <xh@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
+#: ../EventDetails.qml:70
+msgid "Add invite"
 msgstr ""
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr ""
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr ""
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr ""
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr ""
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr ""

=== modified file 'po/zh_CN.po'
--- po/zh_CN.po	2014-04-02 06:45:37 +0000
+++ po/zh_CN.po	2014-03-21 06:52:40 +0000
@@ -7,113 +7,79 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-06-13 11:32+0000\n"
 "Last-Translator: Anthony Wong <anthony.wong@canonical.com>\n"
 "Language-Team: Chinese (Simplified) <zh_CN@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr ""
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr ""
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "添加邀请"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "编辑"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
-msgid "End time can't be before start time"
-msgstr ""
-
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "新建事件"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr ""
-
-#: ../NewEvent.qml:187
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "人物"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "创建事件"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "添加事件名称"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "添加位置"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "邀请他人"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
 msgid "Save"
 msgstr "保存"
 
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr ""
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
 msgstr ""
 
 #. TRANSLATORS: this is a time formatting string,
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr ""
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr ""
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "新建事件"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr ""
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr ""
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr ""
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr ""
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr ""
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "日历"

=== modified file 'po/zh_HK.po'
--- po/zh_HK.po	2014-04-02 06:45:37 +0000
+++ po/zh_HK.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-10-26 07:30+0000\n"
 "Last-Translator: Walter Cheuk <wwycheuk@gmail.com>\n"
 "Language-Team: Chinese (Hong Kong) <zh_HK@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "AP h:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "加入邀請"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "編輯"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "人物"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "建立事件"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "加入事件名稱"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "至"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "位置與人物"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "加入位置"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "邀請人物"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "出錯"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "確定"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "儲存"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "結束時間不能早於開始時間"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "新事件"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "取消"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "儲存"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "出錯"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "分"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "確定"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "取消"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "新事件"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "今天"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "年"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "月"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "週"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "日"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "行事曆"

=== modified file 'po/zh_TW.po'
--- po/zh_TW.po	2014-04-02 06:45:37 +0000
+++ po/zh_TW.po	2014-03-21 06:52:40 +0000
@@ -7,115 +7,81 @@
 msgstr ""
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2014-03-10 19:02-0500\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
 "PO-Revision-Date: 2013-09-28 10:24+0000\n"
 "Last-Translator: Cheng-Chia Tseng <pswo10680@gmail.com>\n"
 "Language-Team: Chinese (Traditional) <zh_TW@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
+"X-Launchpad-Export-Date: 2014-03-21 06:52+0000\n"
 "X-Generator: Launchpad (build 16967)\n"
 
-#: ../AllDayEventComponent.qml:101
-#, c-format, qt-format
-msgid "%1E"
-msgstr ""
-
-#: ../AllDayEventComponent.qml:104
-#, qt-format
-msgid "%1 All day events"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
-#: ../EventBubble.qml:36 ../EventDetails.qml:40
+#: ../EventBubble.qml:38
 msgid "hh:mm"
 msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
-#: ../EventBubble.qml:41
+#: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
 msgstr "%1 - %2"
 
-#: ../EventDetails.qml:98
-msgid "Delete"
-msgstr ""
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "加入邀請"
 
-#: ../EventDetails.qml:110
+#: ../EventDetails.qml:79
 msgid "Edit"
 msgstr "編輯"
 
-#: ../EventDetails.qml:140 ../NewEvent.qml:262
-msgid "Start"
-msgstr ""
-
-#: ../EventDetails.qml:145 ../NewEvent.qml:287
-msgid "End"
-msgstr ""
-
-#: ../EventDetails.qml:153 ../NewEvent.qml:316
-msgid "All Day event:"
-msgstr ""
-
-#: ../EventDetails.qml:183 ../NewEvent.qml:365
-msgid "Location"
-msgstr ""
-
-#: ../EventDetails.qml:207 ../NewEvent.qml:372
-msgid "Guests"
-msgstr ""
-
-#: ../EventDetails.qml:238 ../NewEvent.qml:381
-msgid "This happens"
-msgstr ""
-
-#: ../EventDetails.qml:244 ../NewEvent.qml:398
-msgid "Remind me"
-msgstr ""
-
-#: ../NewEvent.qml:106
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "朋友"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "建立事件"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "加入事件名稱"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr "到"
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "地點與人物"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "加入地點"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "邀請朋友"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "錯誤"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "確定"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "儲存"
+
+#: ../NewEvent.qml:205
 msgid "End time can't be before start time"
 msgstr "結束時間不能早於開始時間"
 
-#: ../NewEvent.qml:165
-msgid "Edit Event"
-msgstr ""
-
-#: ../NewEvent.qml:165 ../calendar.qml:226
-msgid "New Event"
-msgstr "新事件"
-
-#: ../NewEvent.qml:176 ../TimePicker.qml:74
-msgid "Cancel"
-msgstr "取消"
-
-#: ../NewEvent.qml:187
-msgid "Save"
-msgstr "儲存"
-
-#: ../NewEvent.qml:200
-msgid "Error"
-msgstr "錯誤"
-
-#: ../NewEvent.qml:202
-msgid "Ok"
-msgstr ""
-
-#: ../NewEvent.qml:247
-msgid "Date"
-msgstr ""
-
-#: ../NewEvent.qml:334
-msgid "Event Name"
-msgstr ""
-
-#: ../NewEvent.qml:350
-msgid "Description"
-msgstr ""
-
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
@@ -134,36 +100,34 @@
 msgid "Minute"
 msgstr "分鐘"
 
-#: ../TimePicker.qml:83
-msgid "OK"
-msgstr "確定"
-
-#: ../calendar.qml:21
-msgid ""
-"Calendar app accept three arguments: --starttime, --endtime and --newevet. "
-"They will be managed by system. See the source for a full comment about them"
-msgstr ""
-
-#: ../calendar.qml:216
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "取消"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "新事件"
+
+#: ../calendar.qml:64
 msgid "Today"
 msgstr "今日"
 
-#: ../calendar.qml:238
+#: ../calendar.qml:75
 msgid "Year"
 msgstr "年"
 
-#: ../calendar.qml:260
+#: ../calendar.qml:95
 msgid "Month"
 msgstr "月"
 
-#: ../calendar.qml:274
+#: ../calendar.qml:108
 msgid "Week"
 msgstr "週"
 
-#: ../calendar.qml:291
+#: ../calendar.qml:124
 msgid "Day"
 msgstr "日"
 
-#: ../.build/com.ubuntu.calendar_calendar.desktop.in:1
+#: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
 msgstr "行事曆"

=== modified file 'tests/autopilot/calendar_app/tests/test_weekview.py'
--- tests/autopilot/calendar_app/tests/test_weekview.py	2014-03-26 22:03:46 +0000
+++ tests/autopilot/calendar_app/tests/test_weekview.py	2014-02-24 15:58:49 +0000
@@ -154,25 +154,3 @@
         """It must be possible to show previous weeks by swiping the view."""
         for i in range(6):
             self._change_week(-1)
-
-    def test_selecting_a_day_switches_to_day_view(self):
-        """It must be possible to show a single day by clicking on it."""
-        first_day_date = self.week_view.firstDay
-        expected_day = first_day_date.day
-        expected_month = first_day_date.month
-        expected_year = first_day_date.year
-
-        days = self._get_days_of_week()
-        day_to_select = self.main_view.get_label_with_text(days[0])
-
-        self.pointing_device.click_object(day_to_select)
-
-        #Check that the view changed from 'Week' to 'Day'
-        day_view = self.main_view.get_day_view()
-        self.assertThat(day_view.visible, Eventually(Equals(True)))
-
-        #Check that the 'Day' view is on the correct/selected day.
-        selected_date = day_view.select_single("TimeLineHeader").date
-        self.assertThat(expected_day, Equals(selected_date.day))
-        self.assertThat(expected_month, Equals(selected_date.month))
-        self.assertThat(expected_year, Equals(selected_date.year))

